[llvm-commits] CVS: llvm/lib/VMCore/Type.cpp

Misha Brukman brukman at cs.uiuc.edu
Tue May 20 13:46:05 PDT 2003


Changes in directory llvm/lib/VMCore:

Type.cpp updated: 1.44 -> 1.45

---
Log message:

s/convertable/convertible/g


---
Diffs of the changes:

Index: llvm/lib/VMCore/Type.cpp
diff -u llvm/lib/VMCore/Type.cpp:1.44 llvm/lib/VMCore/Type.cpp:1.45
--- llvm/lib/VMCore/Type.cpp:1.44	Tue Jan 14 13:42:39 2003
+++ llvm/lib/VMCore/Type.cpp	Tue May 20 13:45:36 2003
@@ -82,10 +82,10 @@
   }
 }
 
 // isLosslesslyConvertableTo - Return true if this type can be converted to
 // 'Ty' without any reinterpretation of bits.  For example, uint to int.
 //
-bool Type::isLosslesslyConvertableTo(const Type *Ty) const {
+bool Type::isLosslesslyConvertibleTo(const Type *Ty) const {
   if (this == Ty) return true;
   if ((!isPrimitiveType()    && !isa<PointerType>(this)) ||
       (!isa<PointerType>(Ty) && !Ty->isPrimitiveType())) return false;
@@ -82,10 +82,10 @@
 }
 
-// isLosslesslyConvertableTo - Return true if this type can be converted to
+// isLosslesslyConvertibleTo - Return true if this type can be converted to
 // 'Ty' without any reinterpretation of bits.  For example, uint to int.
 //





More information about the llvm-commits mailing list